<?php
namespace Repository;

/**
 * Description of MarketUtilization
 *
 * @author Egrem
 */
class MarketUtilization {

    public function getMarketUtilizationOverview($year, $month, $daymin = 1, $daymax = 31, $whIds = array()) {
        $result = array();

        /*         * ***************Lager***************** */
        $ind = $this->makeInFromArray($whIds);

        $cond = "";
        if ($year > 0) {
            $cond .= " and YEAR(wp.date)=" . (int) $year;
        }
        if ($month > 0) {
            $cond .= " and MONTH(wp.date)=" . (int) $month . " and (DAY(wp.date) BETWEEN " . (int) $daymin . " and " . (int) $daymax . ")";
        }

        $stmt = mysqli_prepare(\Config::getDBConn(),"SELECT DISTINCT it.itid, it.type, tmp.sellprice, it.sort FROM 
                                                        (SELECT it.itid, it.type, SUM(wpe.sellprice) as sellprice
                                                        FROM " . DB_PREFIX . "warehouse_protocoll wp
                                                        JOIN " . DB_PREFIX . "warehouse_protocoll_entry wpe ON wp.wpid=wpe.wpid
                                                        JOIN " . DB_PREFIX . "items i ON wpe.iid=i.iid
                                                        RIGHT JOIN " . DB_PREFIX . "item_types it ON it.itid=i.itid
                                                        WHERE wp.wid " . $ind . $cond . "
                                                        GROUP BY it.itid, it.type
                                                        ORDER BY it.itid) as tmp
                                                    RIGHT JOIN " . DB_PREFIX . "item_types it on it.itid=tmp.itid
                                                    JOIN " . DB_PREFIX . "warehouse w on w.wid ". $ind ."
                                                    JOIN " . DB_PREFIX . "item_types_world itw on itw.itid=it.itid and itw.world=w.world
                                                    ORDER BY it.sort, it.itid");

        $stmt->execute();
        $res = $stmt->get_result();
        
        while($row = $res->fetch_assoc()) {
            $result [] = [
                'itid' => $row['itid'],
                'type' => $row['type'],
                'sellprice' => $row['sellprice'],
                'price_f' => number_format($row['sellprice'], 0, '', '.')
            ];
        }
        
        $stmt->close();
        return $result;
    }

    public function getMarketUtilizationForItid($itId, $year, $month, $daymin = 1, $daymax = 31, $whIds = array()) {
        $result = array();

        /*         * ***************Lager***************** */
        $ind = " and wp.wid" . $this->makeInFromArray($whIds);

        $cond = "";
        if ($year > 0) {
            $cond .= " and YEAR(wp.date)=" . (int) $year;
        }
        if ($month > 0) {
            $cond .= " and MONTH(wp.date)=" . (int) $month . " and (DAY(wp.date) BETWEEN " . (int) $daymin . " and " . (int) $daymax . ")";
        }

        $stmt = mysqli_prepare(\Config::getDBConn(),"SELECT i.itid, i.iid, i.item, SUM(wpe.sellprice) as sellprice, SUM(wpe.icount) as icount, i.magical, i.producable, it.prod_equals_cap_lvl, i.cid
                                                    FROM " . DB_PREFIX . "warehouse_protocoll_entry wpe
                                                    JOIN " . DB_PREFIX . "warehouse_protocoll wp ON wp.wpid=wpe.wpid
                                                    JOIN " . DB_PREFIX . "items i ON wpe.iid=i.iid
                                                    RIGHT JOIN " . DB_PREFIX . "item_types it ON it.itid=i.itid
                                                    WHERE it.itid= ? and sellprice > 0" . $ind . $cond . " 
                                                    GROUP BY i.iid
                                                    ORDER BY i.magical, i.subsort, i.lvl, i.sort");

        $stmt->bind_param('i', $itId);
        $stmt->execute();
        $res = $stmt->get_result();
        
        while($row = $res->fetch_assoc()) {
            $result [] = [
                'iid' => $row['iid'],
                'itid' => $row['itid'],
                'sellprice' => $row['sellprice'],
                'price_f' => number_format($row['sellprice'], 0, '', '.'),
                'icount' => $row['icount'],
                'icount_f' => number_format($row['icount'], 0, '', '.'),
                'item' => $row['item'],
                'magical' => $row['magical'],
                'producable' => $row['producable'],
                'equals' => $row['prod_equals_cap_lvl'],
                'cid' => $row['cid']
            ];               
        }
        
        $stmt->close();
        return $result;
    }

    public function getMarketUtilizationBuyer($year, $month, $daymin = 1, $daymax = 31, $dir, $sort, $whIds = array()) {
        $result = array();
        $dirarr = array('up', 'down');
        $sortarr = array('nick', 'sellprice');

        /*         * ***************Lager***************** */
        $ind = "wp.wid" . $this->makeInFromArray($whIds);

        $cond = "";
        if ($year > 0) {
            $cond .= " and YEAR(wp.date)=" . (int) $year;
        }
        if ($month > 0) {
            $cond .= " and MONTH(wp.date)=" . (int) $month . " and (DAY(wp.date) BETWEEN " . (int) $daymin . " and " . (int) $daymax . ")";
        }

        $order = "";
        if (in_array($sort, $sortarr)) {
            $order = " ORDER BY " . $sort . ($dir == 'up' ? ' ASC' : ' DESC');
        }

         $stmt = mysqli_prepare(\Config::getDBConn(),   "SELECT wp.nick, SUM(wpe.sellprice) as sellprice
                                                        FROM " . DB_PREFIX . "warehouse_protocoll wp
                                                        JOIN " . DB_PREFIX . "warehouse_protocoll_entry wpe ON wp.wpid=wpe.wpid
                                                        WHERE " . $ind . $cond . " and wpe.sellprice > 0
                                                        GROUP BY wp.nick
                                                        " . $order);
        $stmt->execute();
        $res = $stmt->get_result();
        
        while($row = $res->fetch_assoc()) {
            $result [] = [
                'nick' => $row['nick'],
                'sellprice' => $row['sellprice'],
                'price_f'=> number_format($row['sellprice'], 0, '', '.')
            ];
        }
        
        $stmt->close();
        return $result;
    }
    
    public function getItemsForBuyer($nick, $year, $month, $daymin = 1, $daymax = 31, $whIds = array(), $limit = 10) {
        $result = array();

        /*         * ***************Lager***************** */
        $ind = "wp.wid" . $this->makeInFromArray($whIds);

        $cond = "";
        if ($year > 0) {
            $cond .= " and YEAR(wp.date)=" . (int) $year;
        }
        if ($month > 0) {
            $cond .= " and MONTH(wp.date)=" . (int) $month . " and (DAY(wp.date) BETWEEN " . (int) $daymin . " and " . (int) $daymax . ")";
        }

        $stmt = mysqli_prepare(\Config::getDBConn(),   "SELECT wpe.iid, i.item, i.magical, SUM(wpe.icount) as icount, SUM(wpe.sellprice) as sellprice "
                                                    . "FROM " . DB_PREFIX . "warehouse_protocoll wp "
                                                    . "JOIN " . DB_PREFIX . "warehouse_protocoll_entry wpe ON wp.wpid=wpe.wpid "
                                                    . "JOIN " . DB_PREFIX . "items i ON i.iid=wpe.iid "
                                                    . "WHERE " . $ind . $cond . " and wp.nick = ? and wpe.sellprice > 0 "
                                                    . "GROUP BY wp.nick, wpe.iid, i.item, i.magical "
                                                    . "ORDER BY sellprice DESC "
                                                    . "LIMIT ?");

        $entNick = makeEntityString($nick);
        $stmt->bind_param('si', $entNick, $limit);
        $stmt->execute();
        $res = $stmt->get_result();

        while($row = $res->fetch_assoc()) {
            $result [] = [
                'item' => $row['item'],
                'sellprice' => $row['sellprice'],
                'price_f' =>  number_format($row['sellprice'], 0, '', '.'),
                'icount' => $row['icount'],
                'magical' => $row['magical']
            ];
        }
        $stmt->close();
        return $result;
    }

    private function makeInFromArray(array $arr, $default = 0) {
        if (count($arr) > 0) {
            $ind = " IN(";
            $i = 0;

            foreach ($arr as $id) {
                $ind .= $id;
                if ($i != count($arr) - 1) {
                    $ind .= ', ';
                }
                $i++;
            }
            return $ind . ")";
        } else {
            return " IN (" . $default . ")";
        }
    }

}
