<?php

header('Content-Type: application/json');

session_name('sid');
session_start();
require_once '../include/db.php';
require_once('../classes/functions.php');
include_once('../include/auth.php');
require_once('../classes/user.class.php');
require_once '../classes/payment.class.php';
require_once '../classes/guild.class.php';

$user = new User();
$pay = new Payment();

$action = filter_input(INPUT_GET, 'action', FILTER_SANITIZE_STRING) ?? "";
$action2 = filter_input(INPUT_GET, 'action2', FILTER_SANITIZE_STRING) ?? "";

// collect parameters
$year = filter_input(INPUT_GET, 'year', FILTER_VALIDATE_INT);
$guId = filter_input(INPUT_GET, 'gu', FILTER_VALIDATE_INT);
$whId = filter_input(INPUT_GET, 'wh', FILTER_VALIDATE_INT);
$yearf = filter_input(INPUT_GET, 'yearf', FILTER_VALIDATE_INT);
$monthf = filter_input(INPUT_GET, 'monthf', FILTER_VALIDATE_INT);
$yeart = filter_input(INPUT_GET, 'yeart', FILTER_VALIDATE_INT);
$montht = filter_input(INPUT_GET, 'montht', FILTER_VALIDATE_INT);

if ($action2 === 'week') {
    if ($yearf > $yeart && $yeart != 0) {
        $yearf = $yeart;
    }

    if ($yearf == $yeart) {
        if ($monthf > $montht) {
            $montht = $monthf;
        }
    }
}

$chart = [];

if ($action === "monthlypayment") {
    // check access right
    $guild = new Guild($user);
    $guIds = $guild->getGuildsByReadRight();
    if(!$guild->canAccess($guIds, $guId)) {
        echo json_encode([]);
        exit;
    }

    $titletxt = "Gildenkasse " . $year;

    $res = $pay->getPaymentMonthly($year, array($guId));  //werte aus db (Einzahlung, Auszahlung, Monat

    $month = [];
    //Monate in Zaheln durchgehen
    foreach ($res[2] as $val) {
        $month[] = utf8_encode(makeEntityDecodeString(getMonth($val)));
    }

    $chart = [
        'labels' => $month,
        'title' => [
            'display' => true,
            'text' => $titletxt
        ],
        'data' => [
            ['dataset' => [
                    'label' => 'Einzahlung',
                    'data' => $res[0],
                    'backgroundColor' => 'rgba(30, 116, 214, 0.5)',
                    'borderWidth' => 1
                ]],
            ['dataset' => [
                    'label' => 'Entnahme',
                    'data' => $res[1],
                    'backgroundColor' => 'rgba(213, 76, 120, 0.5)',
                    'borderWidth' => 1
                ]]
        ]
    ];
} else if ($action == 'weeklypayment') {
    // check access right
    $guild = new Guild($user);
    $guIds = $guild->getGuildsByReadRight();
    if(!$guild->canAccess($guIds, $guId)) {
        echo json_encode([]);
        exit;
    }
    
    if ($action2 === 'day') {
        $titletxt = 'Gildenkasse ' . utf8_encode(makeEntityDecodeString(getMonth($monthf))) . ' ' . $yearf;
        $legendx = "Tage";
        $res = $pay->getPaymentDayly($yearf, $monthf, $yearf, $monthf, $guId);  //werte aus db (Einzahlung, Auszahlung, Monat			
    } else {
        $titletxt = 'Gildenkasse ' . utf8_encode(makeEntityDecodeString(getMonth($monthf))) . ' ' . $yearf . ' - ' . utf8_encode(makeEntityDecodeString(getMonth($montht))) . ' ' . $yeart;
        $legendx = "Kalenderwochen";
        $res = $pay->getPaymentWeekly($yearf, $monthf, $yeart, $montht, $guId);  //werte aus db (Einzahlung, Auszahlung, Monat
    }

    $kw = [];
    //Monate in Zaheln durchgehen
    foreach ($res[2] as $val) {
        $kw[] = $val;
    }

    $chart = [
        'labels' => $kw,
        'title' => [
            'display' => true,
            'text' => $titletxt
        ],
        'data' => [
            ['dataset' => [
                    'label' => 'Einzahlung',
                    'data' => $res[0],
                    'backgroundColor' => 'rgba(30, 116, 214, 0.5)',
                    'borderColor' => 'rgba(30, 116, 214, 0.5)',
                    'fill' => false,
                    'lineTension' => 0
                ]],
            ['dataset' => [
                    'label' => 'Entnahme',
                    'data' => $res[1],
                    'backgroundColor' => 'rgba(213, 76, 120, 0.5)',
                    'borderColor' => 'rgba(213, 76, 120, 0.5)',
                    'fill' => false,
                    'lineTension' => 0
                ]]
        ]
    ];
} else if ($action == 'weeklywh') {
    require_once('../classes/warehouse.class.php');
    require_once('../classes/summary.class.php');

    $summary = new Summary();
    $wh = new Warehouse($user);

    $whs = $wh->getWHsByReadRight();
    //alle
    if ($whId === 0) {
        foreach ($whs as $val) {
            $whIds[] = $val['wid'];
        }
    } else if ($wh->canAccess($whs, $whId)) {
        $whIds[] = $whId;
    } else {
        $whIds[] = 0;
    }

    if ($action2 == 'day') {
        $titletxt = 'Transaktionen ' . utf8_encode(makeEntityDecodeString(getMonth($monthf))) . ' ' . $yearf;
        $legendx = "Tage";
        $res = $summary->getSummaryListForWhs($whIds, $yearf, $monthf); //$wh->getProtocollListAmounts($whIds, $yearf, $monthf);		
    } else {
        $titletxt = 'Transaktionen ' . utf8_encode(makeEntityDecodeString(getMonth($monthf))) . ' ' . $yearf . ' - ' . utf8_encode(makeEntityDecodeString(getMonth($montht))) . ' ' . $yeart;
        $legendx = "Kalenderwochen";
        $res = $summary->getSummaryListForWhs($whIds, $yearf, $monthf, $yeart, $montht); //$wh->getProtocollListAmounts($whIds, $yearf, $monthf, $yeart, $montht);
    }

    $inkeys = [];   // Monate der Einlagerungen
    $outkeys = [];  // Monate der Entnahmen
    if (isset($res['Einlagerung']) && count($res['Einlagerung']) > 0) {
        $inkeys = array_keys($res['Einlagerung']);
    }

    if (isset($res['Entnahme']) && count($res['Entnahme']) > 0) {
        $outkeys = array_keys($res['Entnahme']);
    }

    $mergearr = array_merge($inkeys, $outkeys);
    //sort($mergearr, SORT_NUMERIC);
    $labelsx = [];
    $vals_plus = [];
    $vals_minus = [];

    foreach ($mergearr as $v) {
        //arrays mit den tagen initialisieren, x-leiste zuweisen
        if (!in_array((string) $v, $labelsx)) {
            $labelsx[] = (string) $v;    //Monat fr x legende
            $vals_plus[] = 0;
            $vals_minus[] = 0;
        }
    }

    if (isset($res['Einlagerung']) && count($res['Einlagerung']) > 0) {
        foreach ($res['Einlagerung'] as $key => $val) {
            //den arraykay suchen der in der x-achse fr den aktuellen tag steht und wert zuweisen
            $k = array_search((string) $key, $labelsx);
            $vals_plus[$k] = (int) $val;      //wert des lagers
        }
    }

    if (isset($res['Entnahme']) && count($res['Entnahme']) > 0) {
        foreach ($res['Entnahme'] as $key => $val) {
            //den arraykay suchen der in der x-achse fr den aktuellen tag steht und wert zuweisen
            $k = array_search((string) $key, $labelsx);
            $vals_minus[$k] = (int) $val;      //wert des lagers
        }
    }

    $chart = [
        'labels' => $labelsx,
        'title' => [
            'display' => true,
            'text' => $titletxt
        ],
        'data' => [
            ['dataset' => [
                    'label' => 'Einlagerung',
                    'data' => $vals_plus,
                    'backgroundColor' => 'rgba(30, 116, 214, 0.5)',
                    'borderColor' => 'rgba(30, 116, 214, 0.5)',
                    'fill' => false,
                    'lineTension' => 0
                ]],
            ['dataset' => [
                    'label' => 'Entnahme',
                    'data' => $vals_minus,
                    'backgroundColor' => 'rgba(213, 76, 120, 0.5)',
                    'borderColor' => 'rgba(213, 76, 120, 0.5)',
                    'fill' => false,
                    'lineTension' => 0
                ]]
        ]
    ];
} else if ($action === "whtype") {
    require_once('../classes/warehouse.class.php');
    require_once('../classes/item.class.php');

    $minmax = $_GET['minmax'] ?? "";

    $item = new Item();
    $wh = new Warehouse($user);
    
    $whs = $wh->getWHsByReadRight();
    //alle
    if (!$wh->canAccess($whs, $whId)) {
        $whId = 0;
    } 
    
    $types = $item->getItemTypes($whId);

    $names = [];
    $values = [];
    $whtot = 0;
    //Monate in Zaheln durchgehen
    foreach ($types as $val) {
        if ($minmax === 'all') {
            $total = $wh->getWhTypePrice($whId, $val['id']);
            $values[] = (int) $total[2];        //wert
            $whtot += $total[2];
        } else if ($minmax === 'min') {
            $total = $wh->getMinMaxType($whId, $val['id']);
            $values[] = (int) $total[4];        //wert
            $whtot += $total[4];
        } else if ($minmax === 'max') {
            $total = $wh->getMinMaxType($whId, $val['id']);
            $values[] = (int) $total[6];        //wert
            $whtot += $total[6];
        }
        $names[] = utf8_encode(makeEntityDecodeString($val['name']));
    }
    $labelsx = $names;
    $titletxt = "Lagerwert: " . number_format($whtot, 0, '', '.') . " Gold";

    $chart = [
        'labels' => $names,
        'title' => [
            'display' => true,
            'text' => $titletxt
        ],
        'data' => [
            ['dataset' => [
                    'label' => 'Warenwert',
                    'data' => $values,
                    'backgroundColor' => 'rgba(30, 116, 214, 0.5)',
                    'borderWidth' => 1
                ]]
        ]
    ];
} else if ($action === "monthlywhpayment") {
    require_once('../classes/warehouse.class.php');
    require_once('../classes/guild.class.php');
    require_once('../classes/summary.class.php');

    $summary = new Summary();
    $guild = new Guild($user);
    $wh = new Warehouse($user);

    $guIds = Array();
    $guilds = $guild->getGuildsByReadRight();
    if ($guId == 0) {        
        foreach ($guilds as $val) {
            $guIds[] = $val['id'];
        }
    } else if($guild->canAccess ($guilds, $guId)) {
        $guIds[] = $guId;
    } else {
        $guIds[] = 0;
    }
    
    $whs = $wh->getWHsByReadRight();
    //alle
    if ($whId === 0) {
        foreach ($whs as $val) {
            $whIds[] = $val['wid'];
        }
    } else if ($wh->canAccess($whs, $whId)) {
        $whIds[] = $whId;
    } else {
        $whIds[] = 0;
    }

    $titletxt = "Kasse + Lager " . $year;

    $vals_plus = [];
    $vals_minus = [];

    //Gildenkasse
    $res = $pay->getPaymentMonthly($year, $guIds);  //werte aus db (Einzahlung, Auszahlung, Monat
    //Lagerprtokoll
    $res2 = $summary->getSummaryListForWhs($whIds, $year); //$wh->getProtocollListAmounts(Array(), $year);

    $i = 0;
    $month =[];
    if (isset($res2['Einlagerung']) && count($res2['Einlagerung']) > 0) {
        foreach ($res2['Einlagerung'] as $key => $val) {
            //prfen ob der monat des Lagers mit dem Monat der Kasse bereinstimmt
            //wenn ja, beide werte hinzufgen, sonst fr kasse 0
            if (in_array($key, $res[2])) {
                $k = array_search($key, $res[2]);    //key anhand des monats fr den zugriff des wertes
                $vals_plus[$i][1] = (int) $res[0][$k];   //wert der kasse
            } else {
                $vals_plus[$i][1] = 0;
            }

            $vals_plus[$i][0] = (int) $val;      //wert des lagers

            $month[] = utf8_encode(makeEntityDecodeString(getMonth($key)));    //Monat fr x legende
            $i++;
        }
    }
    
    $i = 0;
    if (isset($res2['Entnahme']) && count($res2['Entnahme']) > 0) {
        foreach ($res2['Entnahme'] as $key => $val) {
            //prfen ob der monat des Lagers mit dem Monat der Kasse bereinstimmt
            //wenn ja, beide werte hinzufgen, sonst fr kasse 0
            if (in_array($key, $res[2])) {
                $k = array_search($key, $res[2]);    //key anhand des monats fr den zugriff des wertes
                $vals_minus[$i][1] = (int) $res[1][$k];   //wert der kasse
            } else {
                $vals_minus[$i][1] = 0;
            }

            $vals_minus[$i][0] = (int) $val;      //wert des lagers

            $i++;
        }
    }
    $labelsx = $month;

    $vals_plus_wh = [];
    $vals_minus_wh = [];
    $vals_plus_payment = [];
    $vals_minus_payment = [];
    
    // Ergebnis aufsplitten
    // Index 0: Lager, Index 1: Kasse
    // Einlagerungen
    foreach ($vals_plus as $val) {
        ksort($val);
        $vals_plus_wh[] = $val[0];
        $vals_plus_payment[] = $val[1];
    }

    // Entnhamen
    foreach ($vals_minus as $val) {
        ksort($val);
        $vals_minus_wh[] = $val[0];
        $vals_minus_payment[] = $val[1];
    }
    
    $chart = [
        'labels' => $labelsx,
        'title' => [
            'display' => true,
            'text' => $titletxt
        ],
        'data' => [
            ['dataset' => [
                    'label' => 'Einlagerung',
                    'data' => $vals_plus_wh,
                    'backgroundColor' => 'rgba(30, 116, 214, 0.5)',
                    'borderWidth' => 1,
                    'stack' => 'Stack 0'
                ]],
            ['dataset' => [
                    'label' => 'Einzahlung',
                    'data' => $vals_plus_payment,
                    'backgroundColor' => 'rgba(0, 0, 68, 0.5)',
                    'borderWidth' => 1,
                    'stack' => 'Stack 0'
                ]],
            ['dataset' => [
                    'label' => 'Lagerentnahme',
                    'data' => $vals_minus_wh,
                    'backgroundColor' => 'rgba(213, 76, 120, 0.5)',
                    'borderWidth' => 1,
                    'stack' => 'Stack 1'
                ]],
            ['dataset' => [
                    'label' => 'Kassenentnahme',
                    'data' => $vals_minus_payment,
                    'backgroundColor' => 'rgba(153, 0, 0, 0.5)',
                    'borderWidth' => 1,
                    'stack' => 'Stack 1'
                ]]
        ]
    ];
}

echo json_encode($chart);
