<?php

session_name('sid');
session_start();

include_once ('../include/db.php');
include_once('../classes/functions.php');
include_once('../classes/config.class.php');
include_once('../classes/user.class.php');
include_once('../classes/item.class.php');
include_once('../classes/warehouse.class.php');
include_once('../classes/ActivityDiscover.class.php');

$conf = new Config();
$whObj = new Warehouse(null);
$itemObj = new Item();
$acDis = new ActivityDiscover();
$userObj = new User();

$lastCronDate = $conf->getLastActivityDiscoverDate();
$interval = date_diff($lastCronDate, new DateTime());

// update only once a day (every 24h)
// if 0 days between last update and now
//if($interval->format('%a') == 0) {
//    exit; // nothing to do in her
//}

// get all whs
$allWhs = $whObj->getWHs();

$result = Array();
// loop through each wh
foreach($allWhs as $wh) {
    $lastEntry = $whObj->getJungestProtEntry($wh['wid']);
    // wh was never updated through protocol
    if(count($lastEntry) == 0) {
        continue;
    }
    $lastWhDate = new DateTime($lastEntry['date']);
    $diffDays = $lastWhDate->diff($lastCronDate)->format("%a");

    // run script only if last wh date is younger than last cron date and diff within 10 days
    if($lastWhDate < $lastCronDate && $diffDays > 10) {
        continue;
    }

    $itemTypes = $itemObj->getItemTypes($wh['wid']);
    
    // now loop through each item type and check activity of users capabilities
    foreach($itemTypes as $type) {
        if($type['inactive_days'] > 0 && $type['active_amount'] > 0) {
            $cIds = $itemObj->getCapabilitiesIdInItemTypes($type['id']);
            $activityList = $acDis->getWhUserListWithCapLvl($wh['wid'], $type['inactive_days'], $type['id'], $cIds);

            // we got a list of all users which exercice a craft connected to items in the current item types 
            // and the amount they stored into the warehouse in the last $type['inactive_days'] days 
            // now we have to compare the amount with $type['active_amount'] and mark the capapbility for this itid as active or inactive
            foreach($activityList as $activity) {
                // initial value for a capability of a user is always false
                if(!array_key_exists($activity['nick'], $result) || !array_key_exists($activity['cid'], $result[$activity['nick']])) {
                    $result[$activity['nick']][$activity['cid']]['active'] = false;
                    $result[$activity['nick']][$activity['cid']]['activity'] = $activity; // also store current array, we need it later
                }
                // now check if capability was previosly set as true in a nother item type, so we dont have to check it in the current item type
                // true has the highest priority, otherwise we coult overwrite a true with a false
                if($result[$activity['nick']][$activity['cid']]['active'] === true) {
                    continue;
                }

                 // items were stored, now check if he stored enough or not
                if($activity['sumicount'] !== null && $activity['sumicount'] >= $type['active_amount']) {
                    $result[$activity['nick']][$activity['cid']]['active'] = true;
                } 
                // no else needed, because initial value of active was set to false
            }
        }
    }
}
// now loop through all users and update their status of capabilites 
foreach($result as $cap) {
    foreach($cap as $activity) {
        // check if we have to perform an update
        if($activity['active'] != $activity['activity']['mainwork'] && !in_array($activity['activity']['cid'], $userObj->getNoAutoCapDiscoverCids())) {
            $userObj->updateCapActivity($activity['activity']['uid'], $activity['activity']['cid'], $activity['active']);
        }
    }
}

$conf->updateLastActivityDiscoverDate(new DateTime());

