<?php

/**
 * Description of Folk
 *
 * @author Egrem
 */
class Folk {

    private $folks = null;
    private $classesClass = null;
    
    /**
     * Returns a list of all folks including their default base attributes (for the old and new worlds)
     * @return array
     */
    public function getFolks() {
        if($this->folks !== null) {
            return $this->folks;
        }
        $result = Array();
        $query = "SELECT fid, f.name, av.base_value_new, av.base_value_old, av.attributes_id "
                . "FROM " . DB_PREFIX . "folk f LEFT JOIN " . DB_PREFIX . "attributes_values av ON f.fid=av.folks_id "
                . "RIGHT JOIN " . DB_PREFIX . "attributes a ON av.attributes_id=a.aid";

        $res = @mysqli_query(Config::getDBConn(), $query);
        if (mysqli_num_rows($res) > 0) {
            while ($row = mysqli_fetch_array($res)) {
                $result[$row['fid']]['name'] = $row['name'];
                $result[$row['fid']][$row['attributes_id']]['base_old'] = $row['base_value_old'];
                $result[$row['fid']][$row['attributes_id']]['base_new'] = $row['base_value_new'];
            }
        }
        $this->folks = $result;
        return $result;
    }

    /**
     * Returns a list of all classes including the group name of the class
     * @return array
     */
    public function getClasses() {
        $result = [];
        $query = "SELECT cc.id, c.name as groupname, cc.name
                        FROM " . DB_PREFIX . "classes c JOIN " . DB_PREFIX . "classes_class cc ON cc.classes_id=c.id";
        $res = @ mysqli_query(Config::getDBConn(), $query);
        if (mysqli_num_rows($res) > 0) {
            while ($row = mysqli_fetch_array($res)) {
                $result[$row['id']]['name'] = $row['name'];
                $result[$row['id']]['groupname'] = $row['groupname'];
            }
        }
        return $result;
    }

    /**
     * Returns a list of all classes including their base values for each attribut
     * @return array
     */
    public function getClassesClass() {
        if($this->classesClass !== null) {
            return $this->classesClass;
        }
        
        $result = [];
        $query = "SELECT cc.id, cca.attributes_id, cc.name, cca.base_value "
                . "FROM " . DB_PREFIX . "classes_class cc "
                . "LEFT JOIN " . DB_PREFIX . "classes_class_attributes cca ON cca.classes_class_id=cc.id";
        $res = @ mysqli_query(Config::getDBConn(), $query);
        if (mysqli_num_rows($res) > 0) {
            while ($row = mysqli_fetch_array($res)) {
                $result[$row['id']]['name'] = $row['name'];
                $result[$row['id']][$row['attributes_id']]['base_value'] = $row['base_value'];
            }
        }
        $this->classesClass = $result;
        return $result;
    }

    /**
     * Returns the base value for a given attribut and folk and respects the selected class of the chracter
     * @param int $fid Id of the folk
     * @param int $aid Id of the target attribut
     * @param int $classId Id uf the user's class Id
     * @return int
     */
    public function getMinAttributLvl($fid, $aid, $classId) {
        $folks = $this->getFolks();
        $classes = $this->getClassesClass();

        // for the old worlds where no classes are defined
        if ($classId === 0) {
            return $this->getBaseFolkAttributLvl($fid, $aid, $folks) + 5; // folk base level + 5 as base level for all attributes
        } else { // for the new worlds with classes
            if (array_key_exists($classId, $classes) && array_key_exists($aid, $classes[$classId])) {
                $baseLvl = $this->getBaseFolkAttributLvl($fid, $aid, $folks, 'base_new');
                $baseFolkLvl = $baseLvl + 5;    // add + 5 as base level for all attributes
                // get base value for class and add the folk base level
                return $classes[$classId][$aid]['base_value'] + $baseFolkLvl;
            }
        }

        return 0;
    }

    /**
     * Get the base value for the given folk of an attribut
     * @param int $fid
     * @param int $aid
     * @param int $folks
     * @param string $type
     * @return int
     */
    private function getBaseFolkAttributLvl($fid, $aid, $folks, $type = 'base_old') {
        if (array_key_exists($fid, $folks))
            return $folks[$fid][$aid][$type];
        else
            return 0;
    }
}
