
function loadChart(uri, elmId, type, stacked) {
    type = type || 'bar';
    stacked = stacked || false;

    var chart = createChart(elmId, type, stacked);
    getChartData(uri, function (data) {
        updateChart(data, chart);
    });
}

function updateChart(data, chart) {
    //console.log(JSON.stringify(data));
    setLabels(chart, data.labels);
    setTitle(chart, data.title);
    data.data.forEach((datasets) => {
        addDataSet(chart, datasets.dataset);
    });
}

function getChartData(url, successFunc) {
    $.get(url, function (data, status) {
        if (status === "success") {
            successFunc(data);
        }
    });
}

function createChart(elmId, type, stacked) {
    let config = {
        type: type,
        data: {

        },
        options: {
            scales: {
                xAxes: [{
                        stacked: stacked,
                    }],
                yAxes: [{
                        ticks: {
                            beginAtZero: true,
                            callback: function (value, index, values) {
                                return value.toLocaleString('de');
                            }
                        },
                        scaleLabel: {
                            display: true,
                            labelString: 'Gold'
                        },
                        stacked: stacked
                    }]
            },
            tooltips: {
                callbacks: {
                    label: function (tooltipItem, chart) {
                        var datasetLabel = chart.datasets[tooltipItem.datasetIndex].label || '';
                        return datasetLabel + ': ' + tooltipItem.yLabel.toLocaleString('de');
                    }
                }
            }
        }
    }
    let ctx = document.getElementById(elmId).getContext('2d');
    let myChart = new Chart(ctx, config);
    return myChart;
}

function setLabels(chart, labels) {
    chart.data.labels = labels;
    chart.update();
}

function setTitle(chart, title) {
    chart.options.title = title;
    chart.update();
}
function addData(chart, label, data) {
    chart.data.labels.push(label);
    chart.data.datasets.forEach((dataset) => {
        dataset.data.push(data);
    });
    chart.update();
}

function addDataSet(chart, dataset) {
    chart.data.datasets.push(dataset);
    chart.update();
}

function disableSecondMonth()
{
    $(".monthto").attr("disabled", "true");
    $(".yearto").attr("disabled", "true");
}

function enableSecondMonth()
{
    $(".monthto").removeAttr("disabled");
    $(".yearto").removeAttr("disabled");
}

